package cn.minbb.job.controller.rest;

import cn.minbb.job.data.Const;
import cn.minbb.job.data.ResponseResult;
import cn.minbb.job.model.*;
import cn.minbb.job.model.vo.CompanyVo;
import cn.minbb.job.model.vo.JobVo;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.IndustryService;
import cn.minbb.job.service.JobService;
import cn.minbb.job.service.JobTagService;
import cn.minbb.job.system.UserSession;
import com.alibaba.fastjson.JSON;
import lombok.extern.log4j.Log4j2;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

@Log4j2
@RequestMapping("/company")
@RestController
public class CompanyController {

    private final CompanyService companyService;
    private final IndustryService industryService;
    private final JobService jobService;
    private final JobTagService jobTagService;

    public CompanyController(CompanyService companyService, IndustryService industryService, JobService jobService, JobTagService jobTagService) {
        this.companyService = companyService;
        this.industryService = industryService;
        this.jobService = jobService;
        this.jobTagService = jobTagService;
    }

    @PostMapping("/active")
    public ResponseResult<CompanyVo> companyActive(@RequestBody Map<String, String> params) {
        log.info("企业认证入参：{}", params);
        User user = UserSession.getUserAuthentication();
        if (null == user || null == user.getCompany()) {
            return ResponseResult.<CompanyVo>ok(false).code(Const.ReturnCode.FAILED).message("未能获取用户信息").build();
        }
        Company company = companyService.findOneById(user.getCompany().getId());
        String industry = params.get("industry");
        String brand = params.get("brand");
        String nature = params.get("nature");
        String scale = params.get("scale");
        String introduction = params.get("introduction");
        List<Integer> industryIdList = new ArrayList<>();
        for (String item : industry.split(",")) {
            if (!StringUtils.isEmpty(item)) industryIdList.add(Integer.valueOf(item));
        }
        List<Industry> industryList = industryService.findAllByIdIn(industryIdList);
        company.setIndustryList(industryList);
        company.setBrand(brand);
        company.setNature(nature);
        company.setScale(scale);
        company.setIntroduction(introduction);
        company.setIsEnabled(Boolean.TRUE);
        CompanyVo companyVo = JSON.parseObject(JSON.toJSONString(companyService.saveOne(company)), CompanyVo.class);
        return ResponseResult.<CompanyVo>ok(Boolean.TRUE).code(Const.ReturnCode.SUCCESS).message(Const.ReturnMessage.SUCCESS).data(companyVo).build();
    }

    @PostMapping("/job")
    public ResponseResult<JobVo> companyJob(@RequestBody Map<String, String> params) {
        log.info("添加职位入参：{}", params);
        User user = UserSession.getUserAuthentication();
        if (null == user || null == user.getCompany()) {
            return ResponseResult.<JobVo>ok(false).code(Const.ReturnCode.FAILED).message("未能获取用户信息").build();
        }
        Company company = companyService.findOneById(user.getCompany().getId());
        String type = params.get("type");
        String name = params.get("name");
        String salary = params.get("salary");
        String place = params.get("place");
        String education = params.get("education");
        String description = params.get("description");
        String tag = params.get("tag");
        List<Integer> jobTagIdList = new ArrayList<>();
        for (String item : tag.split(",")) {
            if (!StringUtils.isEmpty(item)) jobTagIdList.add(Integer.valueOf(item));
        }
        List<JobTag> jobTagList = jobTagService.findAllByIdIn(jobTagIdList);
        Job job = new Job();
        job.setType(type);
        job.setName(name);
        job.setSalary(salary);
        job.setPlace(place);
        job.setEducation(education);
        job.setDescription(description);
        job.setCompany(company);
        job.setJobTagList(jobTagList);
        job.setIsEnabled(Boolean.TRUE);
        JobVo jobVo = JSON.parseObject(JSON.toJSONString(jobService.saveOne(job)), JobVo.class);
        return ResponseResult.<JobVo>ok(Boolean.TRUE).code(Const.ReturnCode.SUCCESS).message(Const.ReturnMessage.SUCCESS).data(jobVo).build();
    }
}
