package cn.minbb.job.controller.rest;

import cn.minbb.job.data.Const;
import cn.minbb.job.data.ResponseResult;
import cn.minbb.job.enumerate.Role;
import cn.minbb.job.model.Company;
import cn.minbb.job.model.User;
import cn.minbb.job.model.UserRole;
import cn.minbb.job.model.vo.UserVo;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.UserRoleService;
import cn.minbb.job.service.UserService;
import com.alibaba.fastjson.JSON;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

@Log4j2
@RequestMapping("")
@RestController
public class SignController {

    private final CompanyService companyService;
    private final UserService userService;
    private final UserRoleService userRoleService;

    public SignController(CompanyService companyService, UserService userService, UserRoleService userRoleService) {
        this.companyService = companyService;
        this.userService = userService;
        this.userRoleService = userRoleService;
    }

    @PostMapping("/sign-up-user")
    public ResponseResult<UserVo> signUpUser(@RequestBody Map<String, String> params) {
        log.info("注册个人用户入参：{}", params);
        String name = params.get("name");
        String username = params.get("username");
        String password = params.get("password");
        if (userService.existsByUsername(username)) {
            return ResponseResult.<UserVo>ok(false).code(Const.ReturnCode.FAILED).message("用户名已存在").build();
        } else {
            User user = new User(name, username, password);
            Set<UserRole> userRoleSet = new HashSet<>(1);
            userRoleSet.add(userRoleService.findOneByName(Role.USER.name()));
            user.setUserRoleSet(userRoleSet);
            user = userService.saveOne(user);
            UserVo userVo = JSON.parseObject(JSON.toJSONString(user), UserVo.class);
            return ResponseResult.<UserVo>ok(true).code(Const.ReturnCode.SUCCESS).message(Const.ReturnMessage.SUCCESS).data(userVo).build();
        }
    }

    @PostMapping("/sign-up-company")
    public ResponseResult<UserVo> signUpCompany(@RequestBody Map<String, String> params) {
        log.info("注册企业用户入参：{}", params);
        String name = params.get("name");
        String introduction = params.get("introduction");
        String username = params.get("username");
        String password = params.get("password");
        if (userService.existsByUsername(username)) {
            return ResponseResult.<UserVo>ok(false).code(Const.ReturnCode.FAILED).message("用户名已存在").build();
        } else {
            User user = new User(name, username, password);
            Set<UserRole> userRoleSet = new HashSet<>(1);
            userRoleSet.add(userRoleService.findOneByName(Role.COMPANY.name()));
            user.setUserRoleSet(userRoleSet);
            Company company = new Company();
            company.setName(name);
            company.setIntroduction(introduction);
            company.setPriority(0);
            company.setIsEnabled(Boolean.FALSE);
            user.setCompany(company);
            user = userService.saveOne(user);
            UserVo userVo = JSON.parseObject(JSON.toJSONString(user), UserVo.class);
            return ResponseResult.<UserVo>ok(true).code(Const.ReturnCode.SUCCESS).message(Const.ReturnMessage.SUCCESS).data(userVo).build();
        }
    }
}
