package cn.minbb.job.controller.rest;

import cn.minbb.job.data.Const;
import cn.minbb.job.data.ResponseResult;
import cn.minbb.job.model.Resume;
import cn.minbb.job.model.User;
import cn.minbb.job.model.vo.UserVo;
import cn.minbb.job.service.ResumeService;
import cn.minbb.job.service.UserService;
import cn.minbb.job.system.UserSession;
import com.alibaba.fastjson.JSON;
import lombok.extern.log4j.Log4j2;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

@Log4j2
@RequestMapping("/user")
@RestController
public class UserController {

    private final UserService userService;
    private final ResumeService resumeService;

    public UserController(UserService userService, ResumeService resumeService) {
        this.userService = userService;
        this.resumeService = resumeService;
    }

    @PostMapping("/info")
    public ResponseResult<UserVo> userInfo(@RequestBody Map<String, String> params) {
        User user = UserSession.getUserAuthentication();
        if (null == user) {
            return ResponseResult.<UserVo>ok(Boolean.FALSE).code(Const.ReturnCode.FAILED).message("用户未登录").build();
        } else {
            user = userService.findUserByUsername(user.getUsername());
            Resume resume = resumeService.findOneByUserId(user.getId());
            if (null == resume) {
                resume = JSON.parseObject(JSON.toJSONString(params), Resume.class);
            } else {
                Resume obj = JSON.parseObject(JSON.toJSONString(params), Resume.class);
                resume.setName(obj.getName());
                resume.setPhoto(obj.getPhoto());
                resume.setJobPlanning(obj.getJobPlanning());
                resume.setPhone(obj.getPhone());
                resume.setMail(obj.getMail());
                resume.setWebsite(obj.getWebsite());
                resume.setHome(obj.getHome());
                resume.setSignature(obj.getSignature());
                resume.setPlace(obj.getPlace());
                resume.setEduTime(obj.getEduTime());
                resume.setEduSchool(obj.getEduSchool());
                resume.setEduProfession(obj.getEduProfession());
                resume.setWorkTime(obj.getWorkTime());
                resume.setWorkCompany(obj.getWorkCompany());
                resume.setWorkPosition(obj.getWorkPosition());
                resume.setWorkDescription(obj.getWorkDescription());
                resume.setWorkGain(obj.getWorkGain());
                resume.setSkill(obj.getSkill());
                resume.setProject(obj.getProject());
                resume.setHobby(obj.getHobby());
                resume.setDescription(obj.getDescription());
            }
            resume.setUserId(user.getId());
            resume.setIsEnabled(Boolean.TRUE);
            resumeService.saveOne(resume);
        }
        return ResponseResult.<UserVo>ok(Boolean.TRUE).build();
    }
}
