package cn.minbb.job.controller.web;

import cn.minbb.job.data.Const;
import cn.minbb.job.model.Company;
import cn.minbb.job.model.Industry;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.IndustryService;
import lombok.extern.log4j.Log4j2;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
@Log4j2
@RequestMapping("/companies")
public class CompaniesController {

    private final CompanyService companyService;
    private final IndustryService industryService;

    public CompaniesController(CompanyService companyService, IndustryService industryService) {
        this.companyService = companyService;
        this.industryService = industryService;
    }

    @GetMapping({"", "/{industryId}"})
    public ModelAndView companiesPage(
            @PathVariable(name = "industryId", required = false) Integer industryId,
            @RequestParam(name = "page", defaultValue = "1", required = false) Integer page,
            @RequestParam(name = "size", defaultValue = "9", required = false) Integer size,
            ModelAndView modelAndView) {
        List<Industry> industryList = industryService.findAll();
        Industry industry = industryService.findOneById(industryId);
        Page<Company> companyPage;
        if (null != industry) {
            companyPage = companyService.findAllByIndustryIn(industry, page, size);
        } else {
            companyPage = companyService.findAll(page, size);
        }
        List<Company> companyList = companyPage.getContent();
        modelAndView.addObject("companyList", companyList);
        modelAndView.addObject("industryList", industryList);
        modelAndView.addObject(Const.Key.KEY_PAGE, companyPage.getNumber() + 1);
        modelAndView.addObject(Const.Key.KEY_TOTAL_PAGES, companyPage.getTotalPages());
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_COMPANIES);
        modelAndView.setViewName(Const.ViewName.VIEW_COMPANIES);
        return modelAndView;
    }
}
