package cn.minbb.job.controller.web;

import cn.minbb.job.data.Const;
import cn.minbb.job.model.*;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.IndustryService;
import cn.minbb.job.service.JobService;
import cn.minbb.job.service.JobTagService;
import cn.minbb.job.system.UserSession;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

@Controller
@Log4j2
@RequestMapping("/company")
public class CompanyController {

    private final CompanyService companyService;
    private final IndustryService industryService;
    private final JobService jobService;
    private final JobTagService jobTagService;

    public CompanyController(CompanyService companyService, IndustryService industryService, JobService jobService, JobTagService jobTagService) {
        this.companyService = companyService;
        this.industryService = industryService;
        this.jobService = jobService;
        this.jobTagService = jobTagService;
    }

    @GetMapping("")
    public ModelAndView companyPage(@RequestParam(name = "id", required = false) Integer id, ModelAndView modelAndView) {
        Company company = companyService.findOneById(id);
        if (null != company) {
            List<Job> jobList1 = jobService.findAllByCompanyAndType(company, "全职");
            List<Job> jobList2 = jobService.findAllByCompanyAndType(company, "实习");
            company.setPriority(company.getPriority() + 1);
            companyService.saveOne(company);
            modelAndView.addObject("jobList1", jobList1);
            modelAndView.addObject("jobList2", jobList2);
            modelAndView.addObject("company", company);
            modelAndView.setViewName(Const.ViewName.VIEW_COMPANY);
        } else {
            modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT + "companies");
        }
        return modelAndView;
    }

    @GetMapping("/info")
    public ModelAndView companyInfo(HttpServletRequest request, ModelAndView modelAndView) {
        User user = UserSession.getUserAuthentication();
        if (null == user) {
            modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT);
        } else {
            UserSession.updateUserSession(request, user);
            Company company = companyService.findOneById(user.getCompany().getId());
            List<Job> jobList1 = jobService.findAllByCompanyAndType(company, "全职");
            List<Job> jobList2 = jobService.findAllByCompanyAndType(company, "实习");
            List<Industry> industryList = industryService.findAll();
            List<JobTag> jobTagList = jobTagService.findAll();
            modelAndView.addObject("jobList1", jobList1);
            modelAndView.addObject("jobList2", jobList2);
            modelAndView.addObject("jobTagList", jobTagList);
            modelAndView.addObject("industryList", industryList);
            modelAndView.addObject("company", user.getCompany());
            modelAndView.setViewName(Const.ViewName.VIEW_COMPANY_INFO);
        }
        return modelAndView;
    }
}
