package cn.minbb.job.controller.web;

import cn.minbb.job.data.Const;
import cn.minbb.job.model.Company;
import cn.minbb.job.model.Job;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.JobService;
import lombok.extern.log4j.Log4j2;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
@Log4j2
@RequestMapping("/job")
public class JobController {

    private final CompanyService companyService;
    private final JobService jobService;

    public JobController(CompanyService companyService, JobService jobService) {
        this.companyService = companyService;
        this.jobService = jobService;
    }

    @GetMapping("")
    public ModelAndView jobPage(@RequestParam Integer id, ModelAndView modelAndView) {
        Job job = jobService.findOneById(id);
        if (null == job) {
            modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT);
        } else {
            Integer priority = job.getPriority();
            if (null == priority) {
                priority = 1;
            } else {
                priority += 1;
            }
            job.setPriority(priority);
            modelAndView.addObject("job", jobService.saveOne(job));
            modelAndView.setViewName(Const.ViewName.VIEW_JOB);
        }
        return modelAndView;
    }

    @GetMapping("/full")
    public ModelAndView jobFullPage(
            @RequestParam(name = "page", defaultValue = "1", required = false) Integer page,
            @RequestParam(name = "size", defaultValue = "12", required = false) Integer size,
            ModelAndView modelAndView) {
        List<Company> companyTop = companyService.findTop2();
        List<Job> jobTop = jobService.findTop8();
        Page<Job> jobPage = jobService.findAllByTypeWithPage("全职", page, size);
        modelAndView.addObject("companyTop", companyTop);
        modelAndView.addObject("jobTop", jobTop);
        modelAndView.addObject("jobList", jobPage.getContent());
        modelAndView.addObject(Const.Key.KEY_PAGE, jobPage.getNumber() + 1);
        modelAndView.addObject(Const.Key.KEY_TOTAL_PAGES, jobPage.getTotalPages());
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_JOB_FULL);
        modelAndView.setViewName(Const.ViewName.VIEW_JOB_FULL);
        return modelAndView;
    }

    @GetMapping("/practice")
    public ModelAndView jobPracticePage(
            @RequestParam(name = "page", defaultValue = "1", required = false) Integer page,
            @RequestParam(name = "size", defaultValue = "12", required = false) Integer size,
            ModelAndView modelAndView) {
        List<Job> jobTop = jobService.findTop8ByType("实习");
        Page<Job> jobPage = jobService.findAllByTypeWithPage("实习", page, size);
        modelAndView.addObject("jobTop", jobTop);
        modelAndView.addObject("jobList", jobPage.getContent());
        modelAndView.addObject(Const.Key.KEY_PAGE, jobPage.getNumber() + 1);
        modelAndView.addObject(Const.Key.KEY_TOTAL_PAGES, jobPage.getTotalPages());
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_JOB_PRACTICE);
        modelAndView.setViewName(Const.ViewName.VIEW_JOB_PRACTICE);
        return modelAndView;
    }

    @GetMapping("/practice/{sort}")
    public ModelAndView jobPracticeSortPage(
            @PathVariable(required = false) Integer sort,
            @RequestParam(name = "page", defaultValue = "1", required = false) Integer page,
            @RequestParam(name = "size", defaultValue = "12", required = false) Integer size,
            ModelAndView modelAndView) {
        String name = "";
        switch (sort) {
            case 1:
                name = "校园招聘";
                break;
            case 2:
                name = "兼职实习";
                break;
            case 3:
                name = "社会实践";
                break;
            case 4:
                name = "无薪实习";
                break;
        }
        List<Job> jobTop = jobService.findTop8ByTypeAndNameLike("实习", "%" + name + "%");
        Page<Job> jobPage = jobService.findAllByTypeAndNameLikeWithPage("实习", "%" + name + "%", page, size);
        modelAndView.addObject("name", name);
        modelAndView.addObject("jobTop", jobTop);
        modelAndView.addObject("jobList", jobPage.getContent());
        modelAndView.addObject(Const.Key.KEY_PAGE, jobPage.getNumber() + 1);
        modelAndView.addObject(Const.Key.KEY_TOTAL_PAGES, jobPage.getTotalPages());
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_JOB_PRACTICE);
        modelAndView.setViewName(Const.ViewName.VIEW_JOB_PRACTICE);
        return modelAndView;
    }
}
