package cn.minbb.job.controller.web;

import cn.minbb.job.data.Const;
import cn.minbb.job.model.Banner;
import cn.minbb.job.model.Company;
import cn.minbb.job.model.Job;
import cn.minbb.job.service.BannerService;
import cn.minbb.job.service.CompanyService;
import cn.minbb.job.service.JobService;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

import java.util.List;

@Controller
@Log4j2
@RequestMapping("")
public class MainController {

    private final BannerService bannerService;
    private final CompanyService companyService;
    private final JobService jobService;

    public MainController(BannerService bannerService, CompanyService companyService, JobService jobService) {
        this.bannerService = bannerService;
        this.companyService = companyService;
        this.jobService = jobService;
    }

    @GetMapping("")
    public ModelAndView indexPage(ModelAndView modelAndView) {
        List<Banner> bannerList = bannerService.findAll();
        List<Company> companyList = companyService.findTop4();
        List<Job> jobTop = jobService.findTop8();
        List<Job> jobTop1 = jobService.findTop5ByType("全职");
        List<Job> jobTop2 = jobService.findTop5ByType("实习");
        modelAndView.addObject("bannerList", bannerList);
        modelAndView.addObject("companyList", companyList);
        modelAndView.addObject("jobTop", jobTop);
        modelAndView.addObject("jobTop1", jobTop1);
        modelAndView.addObject("jobTop2", jobTop2);
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_INDEX);
        modelAndView.setViewName(Const.ViewName.VIEW_INDEX);
        return modelAndView;
    }

    @GetMapping("/about")
    public ModelAndView aboutPage(ModelAndView modelAndView) {
        modelAndView.addObject(Const.Key.KEY_ACTIVE, Const.ViewName.VIEW_ABOUT);
        modelAndView.setViewName(Const.ViewName.VIEW_ABOUT);
        return modelAndView;
    }
}
