package cn.minbb.job.controller.web;

import cn.minbb.job.data.Const;
import cn.minbb.job.model.Resume;
import cn.minbb.job.model.User;
import cn.minbb.job.service.ResumeService;
import cn.minbb.job.system.UserSession;
import lombok.extern.log4j.Log4j2;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.servlet.ModelAndView;

@Controller
@Log4j2
@RequestMapping("/user")
public class UserController {

    private final ResumeService resumeService;

    public UserController(ResumeService resumeService) {
        this.resumeService = resumeService;
    }

    @GetMapping("/info")
    public ModelAndView infoPage(ModelAndView modelAndView) {
        User user = UserSession.getUserAuthentication();
        if (null == user) {
            modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT);
        } else {
            Resume resume = resumeService.findOneByUserId(user.getId());
            modelAndView.addObject("resume", resume == null ? new Resume() : resume);
            modelAndView.setViewName(Const.ViewName.VIEW_USER_INFO);
        }
        return modelAndView;
    }

    @GetMapping("/resume")
    public ModelAndView resumePage(ModelAndView modelAndView) {
        User user = UserSession.getUserAuthentication();
        if (null == user) {
            modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT);
        } else {
            Resume resume = resumeService.findOneByUserId(user.getId());
            if (null == resume) {
                modelAndView.setViewName(Const.ViewName.VIEW_REDIRECT + "user/info");
            } else {
                modelAndView.addObject("resume", resume);
                modelAndView.setViewName(Const.ViewName.VIEW_USER_RESUME);
            }
        }
        return modelAndView;
    }
}
