package cn.minbb.job.handler;

import cn.minbb.job.data.Const;
import cn.minbb.job.data.ResponseResult;
import cn.minbb.job.util.RequestUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.AuthenticationException;
import org.springframework.security.web.WebAttributes;
import org.springframework.security.web.authentication.SimpleUrlAuthenticationFailureHandler;
import org.springframework.stereotype.Component;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

@Component
@Log4j2
public class LoginAuthenticationFailureHandler extends SimpleUrlAuthenticationFailureHandler {

    private final ObjectMapper objectMapper;

    @Autowired
    public LoginAuthenticationFailureHandler(ObjectMapper objectMapper) {
        this.objectMapper = objectMapper;
    }

    @Override
    public void onAuthenticationFailure(HttpServletRequest request, HttpServletResponse response, AuthenticationException exception) throws IOException, ServletException {
        String message = objectMapper.writeValueAsString(exception.getMessage());
        log.info("用户登录失败 = {}", message);
        if (RequestUtil.isAjax(request)) {
            response.setStatus(HttpStatus.INTERNAL_SERVER_ERROR.value());
            response.setContentType("application/json;charset=UTF-8");
            response.getWriter().write(objectMapper.writeValueAsString(
                    ResponseResult.ok(false).code(Const.ReturnCode.FAILED).message(exception.getMessage()).build()));
        } else {
            // 异常写入 Session
            request.getSession().setAttribute(WebAttributes.AUTHENTICATION_EXCEPTION, exception);
            response.setStatus(HttpStatus.OK.value());
            response.sendRedirect("/login?error=true");
        }
    }
}
