package cn.minbb.job.handler;

import cn.minbb.job.util.RequestUtil;
import com.fasterxml.jackson.databind.ObjectMapper;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.logout.SimpleUrlLogoutSuccessHandler;
import org.springframework.stereotype.Component;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * SimpleUrlLogoutSuccessHandler - 重定向到设置的URL地址。默认的地址是 /login?logout
 * HttpStatusReturningLogoutSuccessHandler - REST API 场景，允许设置一个返回给客户端的 HTTP 状态码（默认返回200）来替换重定向到 URL 这个动作
 */
@Component
@Log4j2
public class LogoutSuccessHandler extends SimpleUrlLogoutSuccessHandler {

    private final ObjectMapper objectMapper;

    @Autowired
    public LogoutSuccessHandler(ObjectMapper objectMapper) {
        this.objectMapper = objectMapper;
    }

    @Override
    public void onLogoutSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication) throws IOException, ServletException {
        String auth = objectMapper.writeValueAsString(authentication);
        log.info("用户登出成功 = {}", auth);
        if (RequestUtil.isAjax(request)) {
            response.setContentType("application/json;charset=UTF-8");
            response.getWriter().write(objectMapper.writeValueAsString(authentication));
        } else {
            response.setStatus(HttpStatus.OK.value());
            response.sendRedirect("/login?logout=true");
            super.onLogoutSuccess(request, response, authentication);
        }
    }
}
