package cn.minbb.job.model;

import lombok.Getter;
import lombok.Setter;
import org.springframework.data.annotation.CreatedBy;
import org.springframework.data.annotation.CreatedDate;
import org.springframework.data.annotation.LastModifiedBy;
import org.springframework.data.annotation.LastModifiedDate;
import org.springframework.data.jpa.domain.support.AuditingEntityListener;

import javax.persistence.*;
import java.util.Date;

@EntityListeners(AuditingEntityListener.class)
@MappedSuperclass
public abstract class Auditable {

    @Getter
    @Setter
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    @Column(name = "id", nullable = false, columnDefinition = "INT COMMENT '自增主键'")
    private Integer id;

    @Getter
    @Setter
    @CreatedBy
    @Column(name = "created_by", updatable = false, columnDefinition = "VARCHAR(200) COMMENT '创建者'")
    protected String createdBy;

    @Getter
    @Setter
    @CreatedDate
    @Column(name = "created_date", nullable = false, updatable = false, columnDefinition = "DATETIME COMMENT '创建日期'")
    protected Date createdDate;

    @Getter
    @Setter
    @LastModifiedBy
    @Column(name = "last_modified_by", columnDefinition = "VARCHAR(200) COMMENT '最后修改者'")
    protected String lastModifiedBy;

    @Getter
    @Setter
    @LastModifiedDate
    @Column(name = "last_modified_date", nullable = false, columnDefinition = "DATETIME COMMENT '最后修改日期'")
    protected Date lastModifiedDate;

    @Version
    @Column(name = "version", nullable = false, columnDefinition = "INT DEFAULT '0' COMMENT '版本号'")
    protected Integer version;
}
