package cn.minbb.job.model;

import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.persistence.*;
import java.util.List;

/**
 * 企业
 */
@Data
@Entity
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@Table(name = "company",
        indexes = {
                @Index(name = "index_name", columnList = "name")
        }
)
public class Company extends Auditable {

    @Column(name = "name", nullable = false, columnDefinition = "VARCHAR(32) COMMENT '名称'")
    private String name;

    @Column(name = "brand", columnDefinition = "MEDIUMTEXT COMMENT '商标'")
    private String brand;

    @Column(name = "introduction", nullable = false, columnDefinition = "VARCHAR(500) COMMENT '简介'")
    private String introduction;

    @Column(name = "nature", columnDefinition = "VARCHAR(16) COMMENT '性质'")
    private String nature;

    @Column(name = "scale", columnDefinition = "VARCHAR(16) COMMENT '规模'")
    private String scale;

    @Column(name = "description", columnDefinition = "VARCHAR(1000) COMMENT '描述'")
    private String description;

    @Column(name = "priority", columnDefinition = "INT DEFAULT '0' COMMENT '优先级'")
    private Integer priority;

    @Column(name = "is_enabled", nullable = false, columnDefinition = "TINYINT DEFAULT '1' COMMENT '启用'")
    private Boolean isEnabled;

    // 行业（集合）
    @ManyToMany(cascade = {CascadeType.MERGE}, fetch = FetchType.EAGER)
    @JoinTable(name = "company_industry",
            joinColumns = {@JoinColumn(name = "company_id", referencedColumnName = "id", columnDefinition = "INT COMMENT '企业ID'")},
            inverseJoinColumns = {@JoinColumn(name = "industry_id", referencedColumnName = "id", columnDefinition = "INT COMMENT '行业ID'")},
            indexes = {
                    @Index(name = "index_company_id", columnList = "company_id"),
                    @Index(name = "index_industry_id", columnList = "industry_id")
            }
    )
    private List<Industry> industryList;
}
