package cn.minbb.job.model;

import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;

import javax.persistence.*;
import java.util.List;

/**
 * 岗位
 */
@Data
@Entity
@EqualsAndHashCode(callSuper = true)
@NoArgsConstructor
@Table(name = "job",
        indexes = {
                @Index(name = "index_name", columnList = "name")
        }
)
public class Job extends Auditable {

    @Column(name = "name", nullable = false, columnDefinition = "VARCHAR(32) COMMENT '名称'")
    private String name;

    @Column(name = "salary", nullable = false, columnDefinition = "VARCHAR(32) COMMENT '薪资待遇'")
    private String salary;

    @Column(name = "place", columnDefinition = "VARCHAR(32) COMMENT '工作地点'")
    private String place;

    @Column(name = "education", columnDefinition = "VARCHAR(32) COMMENT '学历'")
    private String education;

    @Column(name = "type", columnDefinition = "VARCHAR(20) COMMENT '类型'")
    private String type;

    @Column(name = "description", columnDefinition = "VARCHAR(1000) COMMENT '描述'")
    private String description;

    @Column(name = "priority", columnDefinition = "INT COMMENT '优先级'")
    private Integer priority;

    @Column(name = "is_enabled", nullable = false, columnDefinition = "TINYINT DEFAULT '1' COMMENT '启用'")
    private Boolean isEnabled;

    @ManyToOne(cascade = {CascadeType.MERGE}, optional = false)
    @JoinColumn(name = "company_id", columnDefinition = "INT COMMENT '企业ID'")
    private Company company;

    @ManyToMany(cascade = {CascadeType.MERGE})
    @JoinTable(name = "job_job_tag",
            joinColumns = {@JoinColumn(name = "job_id", referencedColumnName = "id", columnDefinition = "INT COMMENT '岗位ID'")},
            inverseJoinColumns = {@JoinColumn(name = "job_tag_id", referencedColumnName = "id", columnDefinition = "INT COMMENT '岗位标签ID'")},
            indexes = {
                    @Index(name = "index_job_id", columnList = "job_id"),
                    @Index(name = "index_job_tag_id", columnList = "job_tag_id")
            }
    )
    private List<JobTag> jobTagList;
}
