package cn.minbb.job.service.impl;

import cn.minbb.job.model.Company;
import cn.minbb.job.model.Job;
import cn.minbb.job.model.repository.JobRepository;
import cn.minbb.job.service.JobService;
import cn.minbb.job.util.PageHelper;
import cn.minbb.job.util.SortTool;
import org.springframework.data.domain.Example;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class JobServiceImpl implements JobService {

    private final JobRepository jobRepository;

    public JobServiceImpl(JobRepository jobRepository) {
        this.jobRepository = jobRepository;
    }

    @Override
    public Job saveOne(Job job) {
        return jobRepository.save(job);
    }

    @Override
    public Job findOneById(Integer id) {
        return jobRepository.findById(id).orElse(null);
    }

    @Override
    public List<Job> findTop8() {
        return jobRepository.findTop8ByIsEnabledTrueOrderByPriorityDesc();
    }

    @Override
    public List<Job> findTop5ByType(String type) {
        return jobRepository.findTop5ByTypeAndIsEnabledTrueOrderByPriorityDesc(type);
    }

    @Override
    public List<Job> findTop8ByType(String type) {
        return jobRepository.findTop8ByTypeAndIsEnabledTrueOrderByPriorityDesc(type);
    }

    @Override
    public List<Job> findTop8ByTypeAndNameLike(String type, String name) {
        return jobRepository.findTop8ByTypeAndNameLikeAndIsEnabledTrueOrderByPriorityDesc(type, name);
    }

    @Override
    public List<Job> findAllByCompanyAndType(Company company, String type) {
        Job job = new Job();
        job.setCompany(company);
        job.setType(type);
        job.setIsEnabled(Boolean.TRUE);
        return jobRepository.findAll(Example.of(job), SortTool.priorityDown());
    }

    @Override
    public Page<Job> findAllByTypeWithPage(String type, Integer page, Integer size) {
        Job job = new Job();
        job.setType(type);
        job.setIsEnabled(Boolean.TRUE);
        return jobRepository.findAll(Example.of(job), PageHelper.of(page, size, SortTool.priorityDown()));
    }

    @Override
    public Page<Job> findAllByTypeAndNameLikeWithPage(String type, String name, Integer page, Integer size) {
        return jobRepository.findAllByTypeAndNameLikeAndIsEnabledTrue(type, name, PageHelper.of(page, size, SortTool.priorityDown()));
    }
}
