package cn.minbb.job.service.impl;

import cn.minbb.job.model.User;
import cn.minbb.job.model.UserRole;
import cn.minbb.job.model.repository.UserRepository;
import cn.minbb.job.service.UserService;
import org.springframework.data.domain.Example;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.CredentialsExpiredException;
import org.springframework.security.authentication.DisabledException;
import org.springframework.security.authentication.LockedException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

@Service
public class UserServiceImpl implements UserService {

    private final UserRepository userRepository;

    public UserServiceImpl(UserRepository userRepository) {
        this.userRepository = userRepository;
    }

    @Override
    public User saveOne(User user) {
        return userRepository.save(user);
    }

    @Override
    public User findOneById(Integer id) {
        return userRepository.findById(id).orElse(null);
    }

    @Override
    public User findUserByUsername(String username) {
        return userRepository.findOneByUsername(username);
    }

    @Override
    public boolean existsByUsername(String username) {
        User user = new User();
        user.setUsername(username);
        return userRepository.exists(Example.of(user));
    }

    @Override
    public UserDetails loadUserByUsername(String s) throws UsernameNotFoundException {
        User user = userRepository.findOneByUsername(s);
        if (user == null) {
            throw new BadCredentialsException("用户名不存在");
        } else {
            if (!user.isAccountNonExpired()) {
                throw new BadCredentialsException("账户已过期");
            } else if (!user.isAccountNonLocked()) {
                throw new LockedException("账户被锁定");
            } else if (!user.isCredentialsNonExpired()) {
                throw new CredentialsExpiredException("凭据已过期");
            } else if (!user.isEnabled()) {
                throw new DisabledException("账户被禁用");
            } else {
                List<GrantedAuthority> grantedAuthorityList = new ArrayList<>();
                Set<UserRole> userRoleSet = user.getUserRoleSet();
                for (UserRole userRole : userRoleSet) {
                    grantedAuthorityList.add(new SimpleGrantedAuthority("ROLE_" + userRole.getRole().name()));
                }
                new org.springframework.security.core.userdetails.User(user.getUsername(), user.getPassword(), grantedAuthorityList);
            }
        }
        return user;
    }
}
