package cn.minbb.job.service.impl;

import cn.minbb.job.model.WebLog;
import cn.minbb.job.model.repository.WebLogRepository;
import cn.minbb.job.service.WebLogService;
import org.springframework.data.jpa.domain.Specification;
import org.springframework.stereotype.Service;

import javax.persistence.criteria.Predicate;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

@Service
public class WebLogServiceImpl implements WebLogService {

    private final WebLogRepository webLogRepository;

    public WebLogServiceImpl(WebLogRepository webLogRepository) {
        this.webLogRepository = webLogRepository;
    }

    @Override
    public WebLog saveOne(WebLog webLog) {
        return webLogRepository.save(webLog);
    }

    @Override
    public WebLog findTop1ByLocationIsNull() {
        return webLogRepository.findTop1ByLocationIsNull();
    }

    @Override
    public List<WebLog> findTop10ByLocationIsNull() {
        return webLogRepository.findTop10ByLocationIsNull();
    }

    @Override
    public List<WebLog> findAllByParamsIn(Date startTime, Date endTime, String uri, String method, String protocol, String userAgent, String ip, String location, String remark) {
        Specification<WebLog> specification = (root, criteriaQuery, criteriaBuilder) -> {
            // 一级查询条件列表
            List<Predicate> predicateList = new ArrayList<>(8);
            if (null != startTime) predicateList.add(criteriaBuilder.greaterThanOrEqualTo(root.get("createdAt"), startTime));
            if (null != endTime) predicateList.add(criteriaBuilder.lessThanOrEqualTo(root.get("createdAt"), endTime));
            if (null != uri) predicateList.add(criteriaBuilder.like(root.get("uri"), uri + "%"));
            if (null != method) predicateList.add(criteriaBuilder.equal(root.get("method"), method));
            if (null != protocol) predicateList.add(criteriaBuilder.like(root.get("protocol"), protocol + "%"));
            if (null != userAgent) predicateList.add(criteriaBuilder.like(root.get("userAgent"), userAgent + "%"));
            if (null != ip) predicateList.add(criteriaBuilder.equal(root.get("ip"), ip));
            if (null != location) predicateList.add(criteriaBuilder.like(root.get("location"), location + "%"));
            if (null != remark) predicateList.add(criteriaBuilder.like(root.get("remark"), remark + "%"));
            criteriaQuery.orderBy(criteriaBuilder.desc(root.get("createdAt")));
            Predicate[] predicates = new Predicate[predicateList.size()];
            // AND 拼接一级查询条件列表
            return criteriaBuilder.and(predicateList.toArray(predicates));
        };
        return webLogRepository.findAll(specification);
    }

    @Override
    public List<Map<String, Integer>> selectPvUvByDateBetween(Date startDate, Date endDate) {
        return webLogRepository.selectPvUvByDateBetween(startDate, endDate);
    }

    @Override
    public int countByDateBetween(Date startTime, Date endTime) {
        return webLogRepository.countByDateBetween(startTime, endTime);
    }
}
