/**
 * 保存成功
 * @param title 标题
 * @param message 提示信息
 */
function adminSaveSuccess(title, message) {
    swal({
        title: title,
        text: message,
        type: "success",
        confirmButtonText: "好的",
        confirmButtonColor: "#2B982B"
    });
}

/**
 * 删除失败
 * @param error 错误信息
 */
function adminDeleteError(error) {
    swal({
        title: "删除失败",
        text: error,
        type: "error",
        confirmButtonText: "好的",
        confirmButtonColor: "#2196F3"
    });
}

/**
 * 通知
 * @param message 提示信息
 * @param colorName 通知样式
 */
function adminNotify(message, colorName) {
    if (message === null || message === '') message = '';
    if (colorName === null || colorName === '') colorName = 'bg-black';
    $.notify({
        message: message
    }, {
        type: colorName,
        allow_dismiss: true,
        newest_on_top: true,
        timer: 1000,
        placement: {from: 'top', align: 'right'},
        animate: {enter: 'animated fadeInDown', exit: 'animated fadeOutUp'},
        template: '' +
            '<div class="bootstrap-notify-container alert alert-dismissible {0} p-r-35" role="alert" data-notify="container">' +
            '    <button class="close" type="button" aria-hidden="true" data-notify="dismiss">×</button>' +
            '    <span data-notify="icon"></span> ' +
            '    <span data-notify="title">{1}</span> ' +
            '    <span data-notify="message">{2}</span>' +
            '    <div class="progress" data-notify="progressbar">' +
            '        <div class="progress-bar progress-bar-{0}" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100" style="width: 0;"></div>' +
            '    </div>' +
            '    <a href="{3}" target="{4}" data-notify="url"></a>' +
            '</div>'
    });
}

/**
 * 内容编辑
 * @param id 内容 ID
 */
function contentEdit(id) {
    window.location.href = '/admin/content/edit?id=' + id;
}

/**
 * 内容预览
 * @param obj
 */
function contentPreview(obj) {
    window.open('/admin/content/preview?id=' + obj.dataset.id);
}

$(function () {
    skinChanger();
    activateNotificationAndTasksScroll();

    setSkinListHeightAndScroll(true);
    setSettingListHeightAndScroll(true);
    $(window).resize(function () {
        setSkinListHeightAndScroll(false);
        setSettingListHeightAndScroll(false);
    });
});

// Skin changer
function skinChanger() {
    $('.right-sidebar .demo-choose-skin li').on('click', function () {
        var $body = $('body');
        var $this = $(this);

        var existTheme = $('.right-sidebar .demo-choose-skin li.active').data('theme');
        $('.right-sidebar .demo-choose-skin li').removeClass('active');
        $body.removeClass('theme-' + existTheme);
        $this.addClass('active');

        $body.addClass('theme-' + $this.data('theme'));
    });
}

// Skin tab content set height and show scroll
function setSkinListHeightAndScroll(isFirstTime) {
    var height = $(window).height() - ($('.navbar').innerHeight() + $('.right-sidebar .nav-tabs').outerHeight());
    var $el = $('.demo-choose-skin');

    if (!isFirstTime) {
        $el.slimScroll({destroy: true}).height('auto');
        $el.parent().find('.slimScrollBar, .slimScrollRail').remove();
    }

    $el.slimscroll({
        height: height + 'px',
        color: 'rgba(0,0,0,0.5)',
        size: '6px',
        alwaysVisible: false,
        borderRadius: '0',
        railBorderRadius: '0'
    });
}

// Setting tab content set height and show scroll
function setSettingListHeightAndScroll(isFirstTime) {
    var height = $(window).height() - ($('.navbar').innerHeight() + $('.right-sidebar .nav-tabs').outerHeight());
    var $el = $('.right-sidebar .demo-settings');

    if (!isFirstTime) {
        $el.slimScroll({destroy: true}).height('auto');
        $el.parent().find('.slimScrollBar, .slimScrollRail').remove();
    }

    $el.slimscroll({
        height: height + 'px',
        color: 'rgba(0,0,0,0.5)',
        size: '6px',
        alwaysVisible: false,
        borderRadius: '0',
        railBorderRadius: '0'
    });
}

// Activate notification and task dropdown on top right menu
function activateNotificationAndTasksScroll() {
    $('.navbar-right .dropdown-menu .body .menu').slimscroll({
        height: '254px',
        color: 'rgba(0,0,0,0.5)',
        size: '4px',
        alwaysVisible: false,
        borderRadius: '0',
        railBorderRadius: '0'
    });
}
